classdef BilinearSystem < MultiEvaluationFunctionalSystem
    
    properties(SetAccess = private)
        P
        Q
    end
    
    methods
        function obj = BilinearSystem(P, Q)
            if ~isa(P, 'LagrangeSystem')
              error('The argument P must be a Lagrange system.'); 
           end
           if ~isa(Q, 'GaussLegendre')
              error('The argument Q must be a GaussLegendre quadrature formula.'); 
           end
           
           bf = P.evaluateAll(Q.points);
           
           we = zeros(P.N*P.N, length(Q.points));
           for i = 1:P.N
              for j = 1:P.N
                  k = (i-1)*P.N + j;
                  we(k, :) = bf(i, :) .* bf(j, :) .* Q.weights;
              end
           end
            
           obj@MultiEvaluationFunctionalSystem(Q.points, we);
           obj.P = P;
           obj.Q = Q;
        end
    end
    
end

