classdef HandleFunctionSystem < FunctionSystem
    
    properties(SetAccess = private)
       handles 
    end
    
    methods
       
        function obj = HandleFunctionSystem(varargin)
           if ~all(cellfun(@(F) isa(F, 'function_handle'), varargin))
              error('All arguments must be function handles'); 
           end
           
           obj.handles = varargin;
           obj.N = length(obj.handles);
        end
        
        function y = evaluate(obj, x)
            if ~isscalar(x)
               error('The argument must be a scalar.'); 
            end
            
            y = cellfun(@(f) f(x), obj.handles)';
        end
        
        %NEU!
        function y = evaluateAll(obj, x)
           if ~isvector(x)
              error('The argument x must be a vector.'); 
           end
           
           %Loop my be faster than arrayfun!
           y = zeros(obj.N, length(x));
           for i = 1:length(x)
               y(:, i) = obj.evaluate(x(i)); 
           end
        end
        
        function f = get(obj, i)
           if ~isscalar(i) || (i < 1) || (i > obj.N)
              error('The argument N is not a suitable index.'); 
           end
           
           f = HandleFunction(obj.handles{i});
        end
    end
    
end

