classdef LagrangeSystem < FunctionSystem
    
    properties(SetAccess = private)
        monoms
        matrix
        points
    end
    
    methods
        function obj = LagrangeSystem(p)
            if ~isvector(p)
               error('The parameter points must be a vector.'); 
            end
            
            obj.N = length(p);
            
            obj.monoms = MonomSystem(obj.N-1);
            obj.points = reshape(p, 1, obj.N);
            
            L = EvaluationFunctionalSystem(obj.points);
            
            M = L.evaluateFunctionSystem(obj.monoms);
            obj.matrix = M \ eye(size(M));
        end
        
        function y = evaluate(obj, x)
            if ~isscalar(x)
               error('The argument must be a scalar.'); 
            end
            
            my = obj.monoms.evaluate(x);
            y = obj.matrix'*my;
        end
        
        %NEU!
        function y = evaluateAll(obj, x)
            if ~isvector(x)
              error('The argument x must be a vector.'); 
            end
            x = reshape(x, 1, length(x));
            
            my = obj.monoms.evaluateAll(x);
            y = obj.matrix'*my;
        end
        
        function f = get(obj, i)
            coords = obj.matrix(:, i);
            
            f = FunSysFunction(obj.monoms, coords);
        end
    end
    
end