classdef MonomSystem < FunctionSystem
    
    properties(SetAccess = private)
        deg
        multiinds
    end
    
    methods
        function obj = MonomSystem(t)
           obj.deg = t;
           
           obj.multiinds = (0:t)';
           obj.N = t+1;
        end
        
        function y = evaluate(obj, x)
            if ~isscalar(x)
               error('The argument must be a scalar.'); 
            end
           
           y = x.^obj.multiinds; 
        end
        
        %NEU!
        function y = evaluateAll(obj, x)
            if ~isvector(x)
              error('The argument x must be a vector.'); 
            end
            
           evlpoints = repmat(reshape(x, 1, length(x)), obj.N, 1);
           inds = repmat(obj.multiinds, 1, length(x));
           
           y = evlpoints .^ inds;
        end
        
        function f = get(obj, i)
            if ~isscalar(i) || (i < 1) || (i > obj.N)
              error('The argument N is not a suitable index.'); 
            end
           
            alpha = obj.multiinds(i);
            f = HandleFunction(@(x) x.^alpha);
        end
    end
    
end

