classdef MultiEvaluationFunctional < Functional
    
    properties
        points
        weights
    end
    
    methods
        function obj = MultiEvaluationFunctional(p, w)
           if ~isvector(p)
              error('The argument p must be a vector.'); 
           end
           if ~isvector(w)
              error('The argument w must be a vector.'); 
           end
           if length(p) ~= length(w)
              error('The vectors p and w must have the same length.'); 
           end
           
           N = length(p); 
           
           obj.points = reshape(p, 1, N);
           obj.weights = reshape(w, 1, N);
        end
        
        function y = of(obj, f)
            if ~isa(f, 'Function')
              error('The first argument must be of type function.'); 
              
            end
            y = sum(f.ofAll(obj.points).*obj.weights);
        end
    end
    
end

