classdef MultiEvaluationFunctionalSystem < FunctionalSystem
    
    properties(SetAccess = protected)
        points
        weights
    end
    
    methods
        function obj = MultiEvaluationFunctionalSystem(p, w)
            if ~isvector(p)
               error('The argument p must be a vector.'); 
            end
            if size(w, 2) ~= length(p)
               error('The argument w has the wrong size.'); 
            end
            
            obj.points = reshape(p, 1, length(p));
            obj.weights = w;
        end
        
        function y = evaluate(obj, f)
            if ~isa(f, 'Function')
              error('The first argument must be of type function.'); 
            end
            
            y = sum(obj.weights .* f.ofAll(obj.points), 2);
        end
        
        function y = evaluateFunctionSystem(obj, F)
            if ~isa(F, 'FunctionSystem')
              error('The first argument must be of type function system.'); 
            end
            
            bf = F.evaluateAll(obj.points);
            y = obj.weights*bf';
        end
        
        function L = get(obj, i)
            if ~isscalar(i) || (i < 1) || (i > size(obj.points, 1))
              error('The argument N is not a suitable index.'); 
            end
            
            L = MultiEvaluationFunctional(obj.points(i,:), obj.weight(i,:));
        end
    end
    
end

